import { Link } from "react-router-dom";
import { PublicUser } from "../Types/goTypes";

/**
 * The props for the UserProps component
 */
interface UserProps {
  users: PublicUser[];
}

/**
 * A list of users for admin manage users page, that links admin to the right user page
 * thanks to the state property
 * @param props - The users to display
 * @returns {JSX.Element} The user list
 * @example
 * const users = [{ id: 1, userName: "Random name" }];
 * return <UserList users={users} />;
 */

export function UserListAdmin(props: UserProps): JSX.Element {
  return (
    <div>
      <ul className="font-bold underline text-[30px] cursor-pointer padding">
        {props.users.map((user) => (
          <Link to="/adminUserInfo" key={user.userId} state={user.username}>
            <li className="pt-5" key={user.userId}>
              {user.username}
            </li>
          </Link>
        ))}
      </ul>
    </div>
  );
}
